"""
Build the documentation, symlinking specific project documentations.
"""
import argparse
import os
import sys

class GenerateDoc(object):

    command_name = 'generate-doc'

    def __init__(self, subparsers=None):
        if subparsers:
            self.parser = parser = subparsers.add_parser(self.command_name,
            description = self.__class__.__doc__)
        else:
            self.parser = parser = argparse.ArgumentParser(
                description=self.__class__.__doc__)

        parser.add_argument('--server', metavar='PATH',
            required=True, help='the local server branch to use for the '
            'server documentation')

        parser.add_argument('--web', metavar='PATH',
            required=True, help='the local web branch to use for the '
            'web documentation')

        parser.add_argument('--output', metavar='PATH',
            default='_result', help='where the documentation is generated')

        parser.set_defaults(run=self.run_with_args)

    def run_with_args(self, args):
        self.args = args
        self.run()

    def run(self):
        l = 'ln -sfT %s server' % os.path.join(
            os.path.abspath(self.args.server), 'doc')
        l = l.split()
        os.spawnvp(os.P_WAIT, l[0], l)

        l = 'ln -sfT %s web' % os.path.join(
            os.path.abspath(self.args.web), 'doc')
        l = l.split()
        os.spawnvp(os.P_WAIT, l[0], l)

        l = 'make clean'.split()
        os.spawnvp(os.P_WAIT, l[0], l)

        l = 'sphinx-build -b dirhtml -d _build/doctrees . _build/dirhtml'.split()
        os.spawnvp(os.P_WAIT, l[0], l)

        l = 'sed -i /-99999/d _build/dirhtml/_static/flasky.css'.split()
        os.spawnvp(os.P_WAIT, l[0], l)

        l = 'rm -rf _result'.split()
        os.spawnvp(os.P_WAIT, l[0], l)

        l = 'cp -r _build/dirhtml %s' % os.path.abspath(self.args.output)
        l = l.split()
        os.spawnvp(os.P_WAIT, l[0], l)

    @classmethod
    def stand_alone(cls):
        command = cls()
        args = command.parser.parse_args()
        args.run(args)

if __name__ == '__main__':
    GenerateDoc.stand_alone()
